==> global_wings-1.0.3.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:global_wings/global_wings.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Material App',
      home: Scaffold(
        appBar: AppBar(
          title: Text('Dev Delight'),
        ),
        body: Home(),
      ),
    );
  }
}

final textdecor = InputDecoration(
    fillColor: Colors.white,
    border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(25.0), borderSide: BorderSide()));

class Home extends StatelessWidget {
  const Home({
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final formKey = GlobalKey<FormState>();
    return Form(
      key: formKey,
      child: Column(
        children: [
          TextFormField(
            decoration: textdecor.copyWith(labelText: 'Name'),
            onSaved: (value) => {save('name', value)},
          ),
          SizedBox(
            height: 10,
          ),
          TextFormField(
            decoration: textdecor.copyWith(labelText: 'Favorite Game'),
            onSaved: (value) => {save('game', value)},
          ),
          MaterialButton(
              child: Text('Save'),
              onPressed: () {
                formKey.currentState.save();
                final snackbar =
                    SnackBar(content: Text(serve('game')));
                Scaffold.of(context).showSnackBar(snackbar);
              })
        ],
      ),
    );
  }
}

==> global_wings-1.0.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:global_wings/global_wings.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    useStore('cart') ;
    // Save Data related to store 
    useStore('product') ;
    // Save Data related to product 
     
    return MaterialApp(
      title: 'Material App',
      home: Scaffold(
        appBar: AppBar(
          title: Text('Dev Delight'),
        ),
        body: Home(),
      ),
    );
    
  }
}



final textdecor = InputDecoration(
    fillColor: Colors.white,
    border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(25.0), borderSide: BorderSide()));

class Home extends StatelessWidget {
  const Home({
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final formKey = GlobalKey<FormState>();
    return Form(
      key: formKey,
      child: Column(
        children: [
          TextFormField(
            decoration: textdecor.copyWith(labelText: 'Name'),
            onSaved: (value) => {save('name', value)},
          ),
          SizedBox(
            height: 10,
          ),
          TextFormField(
            decoration: textdecor.copyWith(labelText: 'Favorite Game'),
            onSaved: (value) => {save('game', value)},
          ),
          MaterialButton(
              child: Text('Save'),
              onPressed: () {
                formKey.currentState.save();
                final snackbar = SnackBar(content: Text(serve('game')));
                Scaffold.of(context).showSnackBar(snackbar);
              })
        ],
      ),
    );
  }
}
